<template>
  <div class="system-add-user-container">
    <el-dialog :title="title" v-model="isShowDialog" width="50%">
      <el-form :model="form" size="default" ref="formRef" :rules="rules" label-width="160px">
        <el-row :gutter="35">
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="培训计划名称" prop="planName">
              <el-input v-model.trim="form.planName" placeholder="培训计划名称" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="培训形式" prop="planMode">
              <el-radio-group v-model="form.planMode">
                <el-radio :label="1">线上</el-radio>
                <el-radio :label="2">线下</el-radio>
              </el-radio-group>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="线下培训印证照片">
              <el-upload accept="image/*" multiple list-type="picture-card" :action="uploadUrl" :headers="header"
                         method="post" :on-exceed="showTip" :on-preview="handlePictureCardPreview"
                         :on-success="handleAvatarSuccess" :limit='2' v-model:file-list="fileList"
                         :before-upload="picSize" :on-remove="handleRemove" :before-remove="beforeRemove">
                <el-icon>
                  <Plus/>
                </el-icon>
                <template #tip>
                  <div class="el-upload__tip">上传图片尺寸小于5M,最多可上传5张</div>
                </template>
              </el-upload>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="培训时间" prop="planBeginTime">
              <el-date-picker
                  v-model="timeRange"
                  @change="changeRange"
                  type="datetimerange"
                  range-separator="至"
                  start-placeholder="开始日期"
                  end-placeholder="结束日期"
                  value-format="YYYY-MM-DD HH:mm:ss"
              />
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20" v-if="title == '新增上报'? false : true">
            <el-form-item label="删除状态" prop="deleted">
              <el-radio-group v-model="form.deleted">
                <el-radio :label="0">未删除</el-radio>
                <el-radio :label="1">已删除</el-radio>
              </el-radio-group>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <el-dialog v-model="imgDialog">
        <img width="100%" :src="imageUrl" alt="Preview Image"/>
      </el-dialog>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="isShowDialog = !isShowDialog" size="default">取 消</el-button>
            <el-button type="primary" v-throttle @click="onSubmit" size="default">确 定</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>

<script lang="ts">
import {reactive, toRefs, onMounted, defineComponent, ref} from 'vue';
import {ElMessageBox, ElMessage} from 'element-plus';
import axios from "axios";
import {workApplyApi} from "/@/api/specialWorkSystem/workApply";
import Cookies from "js-cookie";
import {judgeReportApi} from "/@/api/dataUpload/saftyBaseInfo/judgeReport";
import {educateTrainApi} from "/@/api/dataUpload/educateTrain";

// 定义接口来定义对象的类型
interface DataState {
  title: string
  isShowDialog: boolean
  form: {
    uuid: string
    planName: string
    planMode: number | null
    offlineFile: string
    planBeginTime: string
    planEndTime: string
    deleted: number | null
  }
  timeRange: [],
  rules: {},
  fileList: [],
  uploadUrl: string,
  header: {},
  imgDialog: boolean,
  imageUrl: string
}

export default defineComponent({
  name: 'reportDialog',
  setup(props, context) {
    const formRef = ref()
    const state = reactive<DataState>({
      title: '',
      isShowDialog: false,
      form: {
        uuid: '',
        planName: '',
        planMode: null,
        offlineFile: '',
        planBeginTime: '',
        planEndTime: '',
        deleted: 0,
      },
      rules: {
        planName: [{required: true, message: '请填写培训计划名称', trigger: 'blur'}],
        planMode: [{required: true, message: '请选择培训形式', trigger: 'blur'}],
        planBeginTime: [{required: true, message: '请选择培训开始结束时间', trigger: 'blur'}]
      },
      timeRange: [],
      fileList: [],
      uploadUrl: import.meta.env.VITE_API_URL + '/account/file/upload',
      header: {
        uid: Cookies.get('uid'),
        Authorization: Cookies.get('token')
      },
      imgDialog: false,
      imageUrl: ''
    })

    // 页面加载时
    onMounted(() => {

    })
    // 打开弹窗
    const open = (type: string, data: object) => {
      state.isShowDialog = true;
      if (type === 'add') {
        state.title = '新增上报'
        state.form = {
          uuid: '',
          planName: '',
          planMode: null,
          offlineFile: '',
          planBeginTime: '',
          planEndTime: '',
          deleted: 0,
        }
        state.fileList = []
      } else {
        state.title = '重新上报'
        Object.keys(state.form).forEach(key => {
          if (Object.prototype.hasOwnProperty.call(data, key)) {
            state.form[key] = JSON.parse(JSON.stringify(data))[key];
          }
        })
        state.timeRange = [state.form.planBeginTime,state.form.planEndTime]
        if (data.offlineFile !== '') {
          state.fileList = data.offlineFile.split(',').map((i, index) => {
            return {
              url: i,
              name: i
            }
          })
        } else {
          state.fileList = []
        }

        // state.form = {
        //   uuid: data.uuid,
        //   planName: '',
        //   craftContent: '',
        //   mainProdEquip: '',
        //   keyParts: '',
        //   hazardCode: '',
        //   msds: '',
        //   hazardCharacter: '',
        //   parameterIndex: '',
        //   controlMean: '',
        //   offlineFile: '',
        //   reactionType: '',
        //   keyMonitorUnit: ''
        // }
      }
    };

    const changeRange=(value)=>{
      if(!value){
        state.form.planBeginTime = ""
        state.form.planEndTime = ""
      }else {
        state.form.planBeginTime = state.timeRange[0]
        state.form.planEndTime = state.timeRange[1]
      }
    }

    // 新增修改
    const onSubmit = async () => {
      formRef.value.validate(async (valid: Boolean) => {
        if (valid) {
          state.form.offlineFile = state.fileList.map(i => i.name).join(',')
          const res = await educateTrainApi().addTrainPlan([state.form])
          if (res.data.code == '200') {
            ElMessage({
              type: 'success',
              message: '数据上报成功'
            })
            state.isShowDialog = false
            state.fileList = []
          } else {
            ElMessage({
              type: 'warning',
              message: res.data.msg
            })
          }
          context.emit('refresh')
        } else {
          ElMessage({
            type: 'warning',
            message: '请完善基本信息'
          })
        }
      })
    }

    // 图片上传
    const showTip = () => {
      ElMessage({
        type: 'warning',
        message: '超出文件上传数量'
      });
    }

    const picSize = async (rawFile: any) => {
      if (rawFile.size / 1024 / 1024 > 5) {
        ElMessage({
          type: 'warning',
          message: '文件大小不能超过5M'
        });
        return false
      }
    }

    const handleAvatarSuccess = (res: any, uploadFile: any) => {
      if (res) {
        uploadFile.name = res
      } else {
        ElMessage({
          type: 'warning',
          message: '文件上传失败'
        })
      }
    }

    const handlePictureCardPreview = (uploadFile) => {
      state.imageUrl = uploadFile.url
      state.imgDialog = true;
    }

    const handleRemove = (file, uploadFiles, type) => {
      state.fileList = uploadFiles
    }


    return {
      formRef,
      showTip,
      picSize,
      changeRange,
      handleAvatarSuccess,
      handlePictureCardPreview,
      handleRemove,
      open,
      onSubmit,
      ...toRefs(state)
    };
  }
});
</script>
